#
# spec file for package jaero
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jaero
Version:        1.0.4.13
Release:        1.10
Summary:        A SatCom ACARS demodulator and decoder for the Aero standard
License:        GPL-3.0-or-later AND MIT
Group:          Productivity/Hamradio/Other
URL:            https://jontio.zapto.org/hda1/jaero.html
Source:         https://github.com/jontio/JAERO/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.xz
# Bundled JFFT is licenced under MIT
Source1:        https://github.com/jontio/JFFT/archive/refs/heads/master.zip
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcorrect-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libacars)
BuildRequires:  pkgconfig(libzmq)
BuildRequires:  pkgconfig(qcustomplot)
BuildRequires:  pkgconfig(vorbis)
Requires:       unzip

%description
JAERO is a program that demodulates and decodes Classic Aero ACARS (Aircraft
Communications Addressing and Reporting System) messages sent from satellites to
aeroplanes (SatCom ACARS), commonly used when planes are beyond VHF range.

Demodulation is performed using the soundcard.

Such signals are typically around 1.5Ghz and can be received with a
low-gain antenna that can be home-brewed in conjunction with an
RTL-SDR dongle.

%prep
%setup -q -n JAERO-%{version}
unzip %{SOURCE1} && mv JFFT-master JFFT

%build
mkdir JAERO/build
cd JAERO/build
%qmake5 ..
%make_jobs

%install
install -Dpm 0755 JAERO/build/JAERO  %{buildroot}/%{_bindir}/jaero
install -Dpm 0644 JAERO/images/primary-modem.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%suse_update_desktop_file -c %{name} JAERO "A SatCom ACARS demodulator and decoder for the Aero standard" %{name} %{name} Network HamRadio

%files
%license LICENSE
%doc README.md
%{_bindir}/jaero
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Fri Aug 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.4.13
  * bigger better database.
  * changed plane log to update automatically.
  * changed to JFFT.
  * ZMQ input for SDR receiver application.
  * Plane log window disable to save ram for ppl not wanting it.
  * Source added to statusbar.
- Drop patch:
  * jaero-use-system-libs.patch
* Tue Oct  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.4.11
  * Multiple UDP output destinations allowed (use a space between
    destinations)
  * Window geometry persistence (useful for multiple instances)
  * Fixed crash issue when opening log more than once and scrolling
  * Added libacars uplink messages to plane log
  * Fixed ACARS UDP output stopping when raw UDP output was toggled
  * Merged Jeroen's CPU reduction button.
* Sun Jan 20 2019 mardnh@gmx.de
- Update to version 1.0.4.10
  * Removed std::cout messages
  * Fixed C-Channel assignment freq=0 message bug
* Sat Jan 19 2019 mardnh@gmx.de
- Update to version 1.0.4.9
  * More ACARS message support.
  * 8400bps channels use a raised cosine weighting for locking.
  * 8400bps channels use large complex fasrfir RRC filter before
    the mixer shifted to the approxmate place of the signal.
  * RRC filter for 8400bps channels is 0.6 rather than 1.0.
  * Slowed frequency agility of 8400bps signals.
  * Added detection for stable non carrier detected states.
  * Added AES and GES to the audio file logging names when availible.
  * Delete audio files less then than 10k.
  * Changed audio logging timeout to 2 secs.
  * Reduced 8400bps symbol resonator from 35hz to 10hz.
  * Allowed shifting 8400bps carrier to go less than 4200Hz.
  * 24000Hz bandwith locking just for fun.
  * Optimized 8400bps sample times better.
  * Removed beep from C-Channel assignment.
- Update to version 1.0.4.8
  * Supports demodulation of C channels (8400bps signals).
  * New tab layout.
  * Supports audio codecs.
  * If audio codecs are available it will log audio to disk as
    well as playing it in real time.
  * Fixed libcorrect linking issue on Linux. (you may have to
    still move libcorrect.so into your system libs directory).
  * Added unzip for the different database format on Linux.
    (you will need unzip installed)
- Rename binary to lowercase: JAERO -> jaero
- Specfile cleanup
- Add patch:
  * jaero-use-system-libs.patch
* Sun Jan 28 2018 mardnh@gmx.de
- Update to version 1.0.4.7
  * 1200 C-band burst
  * Soft FEC
  * Reduced CPU load on 600/1200 L-band
* Thu Apr 27 2017 jengelh@inai.de
- Trim filler words from description.
* Mon Apr 24 2017 mpluskal@suse.com
- Use qmake macro and desktop file scriplets
* Thu Apr 13 2017 mardnh@gmx.de
- Update to version 1.0.4.6 (tagged release)
  - specfile cleanup
* Sat Dec 31 2016 mardnh@gmx.de
- Update to version 1.0.4.6.git1483158097.9a11e3c:
  * use https for default csv database file
  * VRS server/client init bug fix
  * Again fix the SBS1 server bug
* Sat Jul 16 2016 mardnh@gmx.de
- Update to version 1.0.4.4.git1468626324.ac704a5:
  * Added changing settings name for multiple program instances
  * Added TCP client
  * TCP ADS output button exclusion
* Tue Mar 22 2016 mardnh@gmx.de
- Update to version 1.0.4.3.git1458616178.1adb29c:
  + SBS1 TCP server for outputting ADS positional information to third-party applications
  + added dual channel 10.5k C-band burst demodulator, time check for sbs1 packets, concatinated sbs1 packets, and added timestamp to sbs1 packets.
* Sat Feb 27 2016 mardnh@gmx.de
- Update to version 1.0.4.1.git1456558015.f89229f:
  + ADS parsing.UDP output for the bottom textedit. Removed unused code.
* Sat Feb 20 2016 mardnh@gmx.de
- Update to version 1.0.4.git1455959486.986efb2:
  + Aero Burst OQPSK Demodulator added. A few Bug fixes.
* Thu Feb  4 2016 mardnh@gmx.de
- Update to version 1.0.3.git1453880854.9cad991:
  + Version number correction
  + tidy
  + Fixed 0x0C packet sat id error and added sat constellation longitude info (tells you where are the sats are out there)
  + Repitition of data in top window and UDP output bug fixed
  + Crash on AES lookup no match bug
  + Spot beam frequency bug
* Sun Jan 10 2016 mardnh@gmx.de
- Update to version 1.0.3.git1452399214.effd5f4:
  + Support for 10.5k signals
  + readme update
* Sat Dec 19 2015 mardnh@gmx.de
- Update to version 1.0.2.git1450429126.4a40fa8:
  + forgotten include for APPDATALOCATIONS define
  + SQLite database for plane database
  + sql minor fix
  + UDP demo app freeze bug workaround
  + import export of log plane log window and reg entry JAEROL to JAERO for settings
  + version number changed in about message box
  + Misc
* Sun Dec 13 2015 mardnh@gmx.de
- Update to version 1.0.1.git1449990951.a55ee17:
  + Linux compatibility and beep sound as a resource
  + Missing first char bug for log and format 3
  + logwindow left right section linking better
  + Linux desktop icon
* Sat Dec 12 2015 mardnh@gmx.de
- Update to version 1.0.1.git1449893963.4a91108:
  + addd database pane, database download button, reg and aes for url subs.
  + log update, beep on text, downloader, misc
  + beep sound
* Thu Dec 10 2015 mardnh@gmx.de
- add --no-as-needed to LDFLAGS to avoid linker issues with libQtSvg
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 1.0.1.git1449561237.3f3d26e:
  + async queued plane image lookup
  + message scrollbar update
  + Basic database plane lookup using csv file in format like http:// junzisun.com/aif/download does it
  + wrong tab
  + log window screenshot update
  + screenshot update
* Sun Dec  6 2015 mardnh@gmx.de
- initial package, version 0.0.0.git1449390850.7cdfbf9
